<p align="center">
  <img src="https://raw.githubusercontent.com/sandy98/oxi/main/oxi/examples/static/img/oxi_1_rounded.jpg" alt="Oxi Logo" width="125px" />

</p>

<h1 align="center">Oxi</h1>

ASGI Full Stack:

* Web Server
* Web App

...and yes, Oxi is a cutie faithful dog!

#### Install

```
pip install oxi
```

#### Usage

`python3 -m oxi`

The latter works serving static files/directories in the same vein that Python's standard library

`python3 -m http.server [port]    #If port isn't specified, it will listen on default port (8086)`

does.

But there's a lot more coming soon.

As it stands in  version 0.2.33, Oxi acts just like a static server. A very efficient, asynchronous one.

Successive incarnations will provide the promised features.

Next step: CGI handling
